==> apache-camel-3.6.0-src.zip: apache-camel-3.6.0/components/camel-saxon/src/test/java/org/apache/camel/component/xquery/XQueryComponentConfigurationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.xquery;

import org.apache.camel.test.spring.junit5.CamelSpringTestSupport;
import org.junit.jupiter.api.Test;
import org.springframework.context.support.ClassPathXmlApplicationContext;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

public class XQueryComponentConfigurationTest extends CamelSpringTestSupport {

    @Test
    public void testConfiguration() throws Exception {
        XQueryComponent component = context.getComponent("xquery", XQueryComponent.class);
        XQueryEndpoint endpoint
                = context.getEndpoint("xquery:org/apache/camel/component/xquery/transform.xquery", XQueryEndpoint.class);

        assertNotNull(component.getConfiguration());
        assertNotNull(component.getConfigurationProperties());
        assertEquals(component.getConfiguration(), endpoint.getConfiguration());
        assertEquals(component.getConfigurationProperties(), endpoint.getConfigurationProperties());
    }

    @Override
    protected ClassPathXmlApplicationContext createApplicationContext() {
        return new ClassPathXmlApplicationContext("org/apache/camel/component/xquery/XQueryComponentConfigurationTest.xml");
    }
}

==> apache-camel-3.22.3-src.zip: apache-camel-3.22.3/components/camel-saxon/src/test/java/org/apache/camel/component/xquery/XQueryComponentConfigurationTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.xquery;

import org.apache.camel.test.spring.junit5.CamelSpringTestSupport;
import org.junit.jupiter.api.Test;
import org.springframework.context.support.AbstractXmlApplicationContext;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertNotNull;

public class XQueryComponentConfigurationTest extends CamelSpringTestSupport {

    @Test
    public void testConfiguration() {
        XQueryComponent component = context.getComponent("xquery", XQueryComponent.class);
        XQueryEndpoint endpoint
                = context.getEndpoint("xquery:org/apache/camel/component/xquery/transform.xquery", XQueryEndpoint.class);

        assertNotNull(component.getConfiguration());
        assertNotNull(component.getConfigurationProperties());
        assertEquals(component.getConfiguration(), endpoint.getConfiguration());
        assertEquals(component.getConfigurationProperties(), endpoint.getConfigurationProperties());
    }

    @Override
    protected AbstractXmlApplicationContext createApplicationContext() {
        return newAppContext("XQueryComponentConfigurationTest.xml");
    }
}
